@@ -1,6 +1,6 @@
 /* io.c - I/O operations */
  
-/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-2000 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdio.h>
@@ -138,7 +138,7 @@ void notify(const UN_CTX *ctx,uint32_t ip,const ENTRY *entry)
     memset(&reply,0,sizeof(reply));
     reply.type = art_query;
     reply.ip = ip;
-    if (entry) reply.addr = *entry->addr;
+    if (entry && entry->addr) reply.addr = *entry->addr;
     if (un_send(ctx,&reply,sizeof(reply)) < 0)
         diag(COMPONENT,DIAG_WARN,"notify: %s",strerror(errno));
 }
