@@ -1,6 +1,6 @@
 /* trace.c - Support functions for message tracing */
  
-/* Written 1996-1999 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1996-2000 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
@@ -9,10 +9,10 @@
 #include <string.h>
 #include <ctype.h>
 #include <sys/time.h>
-#include <stdint.h> /* linux/atmsvc.h includes linux/atm.h */
-#include <linux/atmsvc.h>
 
 #include "atm.h"
+#include <linux/atmsvc.h>
+
 #include "atmd.h"
 #include "atmsap.h"
 #include "trace.h"
@@ -185,9 +185,9 @@ static void print_kernel(void *msg,int size)
       "as_close","as_itf_notify","as_modify","as_identify" };
     struct atmsvc_msg *m = msg;
 
-    append("  %s (vcc 0x%lx, listen_vcc 0x%lx)\n",m->type < sizeof(type)/
-      sizeof(*type) ? type[m->type] : "???",(unsigned long) m->vcc,
-      (unsigned long) m->listen_vcc);
+    append("  %s (vcc %s, listen_vcc %s)\n",m->type < sizeof(type)/
+      sizeof(*type) ? type[m->type] : "???",kptr_print(&m->vcc),
+      kptr_print(&m->listen_vcc));
     append("  reply %d",m->reply);
     if (m->reply) {
 	const char *error;
